@@ -1,6 +1,7 @@
 package Pithub::Users::Keys;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01042';
+
 # ABSTRACT: Github v3 User Keys API
 
 use Moo;
@@ -10,7 +11,8 @@ extends 'Pithub::Base';
 
 sub create {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     return $self->request(
         method => 'POST',
         path   => '/user/keys',
@@ -64,7 +66,7 @@ Pithub::Users::Keys - Github v3 User Keys API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01042
 
 =head1 METHODS
 
